.. include:: ../references.txt

.. _region_reflected:

*****************
Reflected regions
*****************

.. currentmodule:: gammapy.background

Details on the reflected regions method can be found in [Berge2007]_

The following example illustrates how to create reflected regions for a given
circular on region and exclusion mask using the `~gammapy.background.ReflectedRegionsFinder`.

.. plot:: background/make_reflected_regions.py
    :include-source:
